Not a member of Pastebin yet?
Sign Up,
it unlocks many cool features!
- [20:28:50] [ServerMain/INFO]: [bootstrap] Running Java 21 (OpenJDK 64-Bit Server VM 21.0.8+9-Ubuntu-0ubuntu124.04.1; Ubuntu null) on Linux 6.8.0-85-generic (amd64)
- [20:28:50] [ServerMain/INFO]: [bootstrap] Loading Paper 1.21.5-114-ver/1.21.5@a1b3058 (2025-06-18T10:59:02Z) for Minecraft 1.21.5
- [20:28:50] [ServerMain/INFO]: [PluginInitializerManager] Initializing plugins...
- [20:28:51] [ServerMain/INFO]: [PluginInitializerManager] Initialized 14 plugins
- [20:28:51] [ServerMain/INFO]: [PluginInitializerManager] Bukkit plugins (14):
- - AxiomPaper (5.0.1+1.21.5), LibsDisguises (11.0.9), MMOCore (1.13.1-SNAPSHOT), MMOInventory (2.0-SNAPSHOT), MMOItems (6.10.1-SNAPSHOT), MythicCrucible (2.2.0-SNAPSHOT), MythicHUD (1.3.1-SNAPSHOT), MythicLib (1.7.1-SNAPSHOT), MythicMobs (5.10.1-SNAPSHOT-ae8b9c3d), PlaceholderAPI (2.11.6), ProtocolLib (5.4.0), SimpleScore (4.0.1), WorldEdit (7.3.16+cbf4bd5), packetevents (2.10.0)
- [20:28:53] [ServerMain/WARN]: resource-pack-id missing, using default of 1a6401bc-1109-3ba0-b0e8-aadf244daa60
- [20:28:53] [ServerMain/INFO]: Environment: Environment[sessionHost=https://sessionserver.mojang.com, servicesHost=https://api.minecraftservices.com, name=PROD]
- [20:28:53] [ServerMain/INFO]: Loaded 1373 recipes
- [20:28:53] [ServerMain/INFO]: Loaded 1484 advancements
- [20:28:53] [Server thread/INFO]: Starting minecraft server version 1.21.5
- [20:28:53] [Server thread/INFO]: Loading properties
- [20:28:54] [Server thread/INFO]: This server is running Paper version 1.21.5-114-ver/1.21.5@a1b3058 (2025-06-18T10:59:02Z) (Implementing API version 1.21.5-R0.1-SNAPSHOT)
- [20:28:54] [Server thread/INFO]: [spark] This server bundles the spark profiler. For more information please visit https://docs.papermc.io/paper/profiling
- [20:28:54] [Server thread/INFO]: Server Ping Player Sample Count: 12
- [20:28:54] [Server thread/INFO]: Using 4 threads for Netty based IO
- [20:28:54] [Server thread/INFO]: [MoonriseCommon] Paper is using 5 worker threads, 1 I/O threads
- [20:28:54] [Server thread/INFO]: [ChunkTaskScheduler] Chunk system is using population gen parallelism: true
- [20:28:54] [Server thread/INFO]: Default game type: SURVIVAL
- [20:28:54] [Server thread/INFO]: Generating keypair
- [20:28:54] [Server thread/INFO]: Starting Minecraft server on *:25565
- [20:28:54] [Server thread/INFO]: Using epoll channel type
- [20:28:54] [Server thread/INFO]: Paper: Using libdeflate (Linux x86_64) compression from Velocity.
- [20:28:54] [Server thread/INFO]: Paper: Using OpenSSL 3.x.x (Linux x86_64) cipher from Velocity.
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loading 4 libraries... please wait
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-api/4.16.0/adventure-api-4.16.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-key/4.16.0/adventure-key-4.16.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/examination-api/1.3.0/examination-api-1.3.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/examination-string/1.3.0/examination-string-1.3.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/org/jetbrains/annotations/24.1.0/annotations-24.1.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-bukkit/4.3.2/adventure-platform-bukkit-4.3.2.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-api/4.3.2/adventure-platform-api-4.3.2.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-bungeecord/4.3.2/adventure-text-serializer-bungeecord-4.3.2.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-legacy/4.13.1/adventure-text-serializer-legacy-4.13.1.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-nbt/4.13.1/adventure-nbt-4.13.1.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-gson-legacy-impl/4.13.1/adventure-text-serializer-gson-legacy-impl-4.13.1.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-facet/4.3.2/adventure-platform-facet-4.3.2.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-platform-viaversion/4.3.2/adventure-platform-viaversion-4.3.2.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-minimessage/4.16.0/adventure-text-minimessage-4.16.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-gson/4.16.0/adventure-text-serializer-gson-4.16.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/adventure-text-serializer-json/4.16.0/adventure-text-serializer-json-4.16.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/net/kyori/option/1.0.0/option-1.0.0.jar
- [20:28:54] [Server thread/INFO]: [SpigotLibraryLoader] [MythicMobs] Loaded library /home/ProjectCrimson/server/libraries/com/google/code/gson/gson/2.8.0/gson-2.8.0.jar
- [20:28:54] [Server thread/INFO]: [ProtocolLib] Loading server plugin ProtocolLib v5.4.0
- [20:28:55] [Server thread/INFO]: [packetevents] Loading server plugin packetevents v2.10.0
- [20:28:55] [Server thread/INFO]: [PlaceholderAPI] Loading server plugin PlaceholderAPI v2.11.6
- [20:28:55] [Server thread/INFO]: [LibsDisguises] Loading server plugin LibsDisguises v11.0.9
- [20:28:55] [Server thread/INFO]: [MythicMobs] Loading server plugin MythicMobs v5.10.1-SNAPSHOT-ae8b9c3d
- [20:28:55] [Server thread/INFO]: [LumineUtils] (io.lumine.mythic.bukkit.utils.) is bound to plugin MythicMobs - io.lumine.mythic.bukkit.MythicBukkit
- [20:28:55] [Server thread/INFO]: [MythicMobs] §x§f§f§0§0§0§0M§x§f§f§6§6§0§0y§x§f§f§c§c§0§0t§x§c§b§f§f§0§0h§x§6§5§f§f§0§0i§x§0§0§f§f§0§0c§x§0§0§f§f§6§6 §x§0§0§f§f§c§bE§x§0§0§c§b§f§fn§x§0§0§6§5§f§fa§x§0§0§0§0§f§fb§x§6§6§0§0§f§fl§x§c§c§0§0§f§fe§x§f§f§0§0§c§cd§x§f§f§0§0§6§6!
- [20:28:55] [Server thread/INFO]: [MythicLib] Loading server plugin MythicLib v1.7.1-SNAPSHOT
- [20:28:55] [Server thread/INFO]: [MythicLib] Plugin file is called 'MythicLib-dist-1.7.1-20251023.125447-44.jar'
- [20:28:55] [Server thread/INFO]: [MythicLib] Detected Bukkit Version: v1_21_R4
- [20:28:55] [Server thread/INFO]: [MMOCore] Loading server plugin MMOCore v1.13.1-SNAPSHOT
- [20:28:55] [Server thread/INFO]: [MMOCore] Plugin file is called 'MMOCore-1.13.1-20251020.220648-27 (1).jar'
- [20:28:55] [Server thread/INFO]: [MMOItems] Loading server plugin MMOItems v6.10.1-SNAPSHOT
- [20:28:55] [Server thread/INFO]: [MMOItems] Plugin file is called 'MMOItems-6.10.1-20251022.221410-36.jar'
- [20:28:55] [Server thread/INFO]: [MMOItems] Hooked onto WorldEdit
- [20:28:56] [Server thread/INFO]: [MMOItems Template Modifiers] Preloading template modifiers, please wait..
- [20:28:56] [Server thread/INFO]: [MMOItems Item Templates] Preloading item templates, please wait..
- [20:28:56] [Server thread/INFO]: [MMOItems] Hooked onto MythicMobs
- [20:28:56] [Server thread/INFO]: [MythicCrucible] Loading server plugin MythicCrucible v2.2.0-SNAPSHOT
- [20:28:56] [Server thread/INFO]: [MythicHUD] Loading server plugin MythicHUD v1.3.1-SNAPSHOT
- [20:28:56] [Server thread/INFO]: [AxiomPaper] Loading server plugin AxiomPaper v5.0.1+1.21.5
- [20:28:56] [Server thread/INFO]: [SimpleScore] Loading server plugin SimpleScore v4.0.1
- [20:28:56] [Server thread/INFO]: [WorldEdit] Loading server plugin WorldEdit v7.3.16+cbf4bd5
- [20:28:56] [Server thread/INFO]: Got request to register class com.sk89q.worldedit.bukkit.BukkitServerInterface with WorldEdit [com.sk89q.worldedit.extension.platform.PlatformManager@791276df]
- [20:28:56] [Server thread/INFO]: [MMOInventory] Loading server plugin MMOInventory v2.0-SNAPSHOT
- [20:28:56] [Server thread/INFO]: [MMOInventory] Plugin file is called 'MMOInventory-2.0-20251023.122947-14.jar'
- [20:28:56] [Server thread/INFO]: Server permissions file permissions.yml is empty, ignoring it
- [20:28:56] [Server thread/INFO]: [ProtocolLib] Enabling ProtocolLib v5.4.0
- [20:28:56] [Server thread/INFO]: [WorldEdit] Enabling WorldEdit v7.3.16+cbf4bd5
- [20:28:56] [Server thread/INFO]: Registering commands with com.sk89q.worldedit.bukkit.BukkitServerInterface
- [20:28:56] [Server thread/INFO]: WEPIF: Using the Bukkit Permissions API.
- [20:28:56] [Server thread/INFO]: Using com.sk89q.worldedit.bukkit.adapter.impl.v1_21_5.PaperweightAdapter as the Bukkit adapter
- [20:28:56] [Server thread/WARN]: **** SERVER IS RUNNING IN OFFLINE/INSECURE MODE!
- [20:28:56] [Server thread/WARN]: The server will make no attempt to authenticate usernames. Beware.
- [20:28:56] [Server thread/WARN]: While this makes the game possible to play without internet access, it also opens up the ability for hackers to connect with any username they choose.
- [20:28:56] [Server thread/WARN]: To change this, set "online-mode" to "true" in the server.properties file.
- [20:28:56] [Server thread/INFO]: Preparing level "world"
- [20:28:57] [Server thread/INFO]: Preparing start region for dimension minecraft:overworld
- [20:28:57] [Server thread/INFO]: Preparing spawn area: 0%
- [20:28:57] [Server thread/INFO]: Time elapsed: 383 ms
- [20:28:57] [Server thread/INFO]: Preparing start region for dimension minecraft:the_nether
- [20:28:57] [Server thread/INFO]: Preparing spawn area: 0%
- [20:28:57] [Server thread/INFO]: Time elapsed: 40 ms
- [20:28:57] [Server thread/INFO]: Preparing start region for dimension minecraft:the_end
- [20:28:57] [Server thread/INFO]: Preparing spawn area: 0%
- [20:28:57] [Server thread/INFO]: Time elapsed: 28 ms
- [20:28:57] [Server thread/INFO]: [packetevents] Enabling packetevents v2.10.0
- [20:28:57] [packetevents-update-check-thread/INFO]: [packetevents] Checking for updates, please wait...
- [20:28:57] [Server thread/INFO]: [PlaceholderAPI] Enabling PlaceholderAPI v2.11.6
- [20:28:57] [Server thread/INFO]: [PlaceholderAPI] Fetching available expansion information...
- [20:28:57] [Server thread/INFO]: [LibsDisguises] Enabling LibsDisguises v11.0.9
- [20:28:57] [Server thread/INFO]: [LibsDisguises] File Name: LibsDisguises-11.0.9-Free.jar
- [20:28:57] [Server thread/INFO]: [LibsDisguises] Discovered nms version: (Package: {Not package relocated}) (LD: v1_21_R4) (MC: 1.21.5)
- [20:28:57] [Server thread/INFO]: [LibsDisguises] Jenkins Build: #1637
- [20:28:57] [Server thread/INFO]: [LibsDisguises] Build Date: 11/09/2025 04:26
- [20:28:57] [Server thread/INFO]: [LibsDisguises] If you own the plugin, place the premium jar downloaded from https://www.spigotmc.org/resources/libs-disguises.32453/ in plugins/LibsDisguises/
- [20:28:57] [Server thread/INFO]: [LibsDisguises] You are running the free version, commands limited to non-players and operators. (Console, Command Blocks, Admins)
- [20:28:57] [Server thread/INFO]: [LibsDisguises] Config 'TallSelfDisguises' is set to 'SCALED', LD will scale down (when possible) oversized disguises from self disguise. https://www.spigotmc.org/wiki/lib-s-disguises-faq/#tall-disguises-self-disguises
- [20:28:57] [packetevents-update-check-thread/INFO]: [packetevents] You are running the latest release of PacketEvents. Your build: (2.10.0)
- [20:28:58] [Server thread/INFO]: [com.github.retrooper.packetevents.PacketEventsAPI] Loading block mappings for V_1_21_5/18...
- [20:28:58] [Server thread/INFO]: [com.github.retrooper.packetevents.PacketEventsAPI] Finished loading block mappings for V_1_21_5/18 in 124.901551ms
- [20:28:58] [Yggdrasil Key Fetcher/ERROR]: Failed to request yggdrasil public key
- com.mojang.authlib.exceptions.MinecraftClientException: Failed to read from https://api.minecraftservices.com/publickeys due to Read timed out
- at com.mojang.authlib.minecraft.client.MinecraftClient.readInputStream(MinecraftClient.java:111) ~[authlib-6.0.58.jar:?]
- at com.mojang.authlib.minecraft.client.MinecraftClient.get(MinecraftClient.java:56) ~[authlib-6.0.58.jar:?]
- at com.mojang.authlib.yggdrasil.YggdrasilServicesKeyInfo.fetch(YggdrasilServicesKeyInfo.java:114) ~[authlib-6.0.58.jar:?]
- at com.mojang.authlib.yggdrasil.YggdrasilServicesKeyInfo$1.run(YggdrasilServicesKeyInfo.java:89) ~[authlib-6.0.58.jar:?]
- at java.base/java.util.concurrent.Executors$RunnableAdapter.call(Executors.java:572) ~[?:?]
- at java.base/java.util.concurrent.FutureTask.run(FutureTask.java:317) ~[?:?]
- at java.base/java.util.concurrent.ScheduledThreadPoolExecutor$ScheduledFutureTask.run(ScheduledThreadPoolExecutor.java:304) ~[?:?]
- at java.base/java.util.concurrent.ThreadPoolExecutor.runWorker(ThreadPoolExecutor.java:1144) ~[?:?]
- at java.base/java.util.concurrent.ThreadPoolExecutor$Worker.run(ThreadPoolExecutor.java:642) ~[?:?]
- at java.base/java.lang.Thread.run(Thread.java:1583) ~[?:?]
- Caused by: java.net.SocketTimeoutException: Read timed out
- at java.base/sun.nio.ch.NioSocketImpl.timedRead(NioSocketImpl.java:278) ~[?:?]
- at java.base/sun.nio.ch.NioSocketImpl.implRead(NioSocketImpl.java:304) ~[?:?]
- at java.base/sun.nio.ch.NioSocketImpl.read(NioSocketImpl.java:346) ~[?:?]
- at java.base/sun.nio.ch.NioSocketImpl$1.read(NioSocketImpl.java:796) ~[?:?]
- at java.base/java.net.Socket$SocketInputStream.read(Socket.java:1099) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketInputRecord.read(SSLSocketInputRecord.java:489) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketInputRecord.readHeader(SSLSocketInputRecord.java:483) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketInputRecord.decode(SSLSocketInputRecord.java:160) ~[?:?]
- at java.base/sun.security.ssl.SSLTransport.decode(SSLTransport.java:111) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketImpl.decode(SSLSocketImpl.java:1506) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketImpl.readHandshakeRecord(SSLSocketImpl.java:1421) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketImpl.startHandshake(SSLSocketImpl.java:455) ~[?:?]
- at java.base/sun.security.ssl.SSLSocketImpl.startHandshake(SSLSocketImpl.java:426) ~[?:?]
- at java.base/sun.net.www.protocol.https.HttpsClient.afterConnect(HttpsClient.java:586) ~[?:?]
- at java.base/sun.net.www.protocol.https.AbstractDelegateHttpsURLConnection.connect(AbstractDelegateHttpsURLConnection.java:187) ~[?:?]
- at java.base/sun.net.www.protocol.http.HttpURLConnection.getInputStream0(HttpURLConnection.java:1691) ~[?:?]
- at java.base/sun.net.www.protocol.http.HttpURLConnection.getInputStream(HttpURLConnection.java:1615) ~[?:?]
- at java.base/java.net.HttpURLConnection.getResponseCode(HttpURLConnection.java:531) ~[?:?]
- at java.base/sun.net.www.protocol.https.HttpsURLConnectionImpl.getResponseCode(HttpsURLConnectionImpl.java:307) ~[?:?]
- at com.mojang.authlib.minecraft.client.MinecraftClient.readInputStream(MinecraftClient.java:82) ~[authlib-6.0.58.jar:?]
- ... 9 more
- [20:28:58] [Server thread/INFO]: [LibsDisguises] Config is up to date!
- [20:28:58] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: libsdisguises [1.0.0]
- [20:28:58] [Server thread/INFO]: [LibsDisguises] PlaceholderAPI support enabled
- [20:28:58] [Server thread/INFO]: [MythicMobs] Enabling MythicMobs v5.10.1-SNAPSHOT-ae8b9c3d
- [20:28:58] [Server thread/INFO]: [MythicMobs] Loading MythicMobs for Paper (MC: 1.21.5)...
- [20:28:58] [Server thread/INFO]: [MythicMobs] The server is running Paper; enabled Paper exclusive functionality
- [20:28:59] [Server thread/INFO]: [MythicMobs] Mythic LibsDisguises Support has been enabled!
- [20:28:59] [Server thread/INFO]: [MythicMobs] Mythic MMOItems Support has been enabled!
- [20:28:59] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mythic [5.0.0]
- [20:28:59] [Server thread/INFO]: [MythicMobs] Mythic PlaceholderAPI Support has been enabled!
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Packs...
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Items...
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Item Groups...
- [20:29:01] [Server thread/INFO]: [MythicMobs] All items loaded after 21ms!
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Skills...
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Drop Tables...
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Random Spawns...
- [20:29:01] [Server thread/INFO]: [MythicMobs] Loading Spawn Blocks...
- [20:29:01] [Server thread/INFO]: [MythicMobs] Second passes loaded after 11ms!
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 8 mobs.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 3 vanilla mob overrides.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 0 mob stacks.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 85 skills.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 0 random spawns.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 3 mythic items.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 2 drop tables.
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ Loaded 0 mob spawners.
- [20:29:01] [Server thread/INFO]: [MythicMobs] MythicMobs configuration file loaded successfully.
- [20:29:01] [Server thread/INFO]: [MythicMobs] Started up bStats Metrics
- [20:29:01] [Server thread/INFO]: [MythicMobs] ✓ MythicMobs Premium v5.10.1 ( build ae8b9c3d ) has been successfully loaded!
- [20:29:01] [Server thread/INFO]: [MythicLib] Enabling MythicLib v1.7.1-SNAPSHOT
- [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto TextDisplays (holograms)
- [20:29:01] [Server thread/INFO]: [MythicMobs] MMO Plugin Support has been enabled!
- [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto MythicMobs
- [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto ProtocolLib
- [20:29:01] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mythiclib [1.7.1-SNAPSHOT]
- [20:29:01] [Server thread/INFO]: [MythicLib] Hooked onto PlaceholderAPI
- [20:29:01] [Server thread/INFO]: Environment: Environment[sessionHost=https://sessionserver.mojang.com, servicesHost=https://api.minecraftservices.com, name=PROD]
- [20:29:01] [Server thread/INFO]: [MMOCore] Enabling MMOCore v1.13.1-SNAPSHOT
- [20:29:01] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mmocore [1.13.1-SNAPSHOT]
- [20:29:01] [Server thread/INFO]: [MMOCore] Hooked onto PlaceholderAPI
- [20:29:01] [Server thread/INFO]: [MMOCore] Hooked onto MythicMobs
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load language entry 'gold-pouch-ui-name': Entry not found
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'guild-no-pending-invite': Translation not found
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'friend-no-pending-invite': Translation not found
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'party-no-pending-invite': Translation not found
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load message 'no-class-skill-tree': Translation not found
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load custom mining condition 'region{name="example_region,example_region2,__global__"}': Could not match any condition to 'region' in database
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load custom mining condition 'region{name="example_region,example_region2,__global__"}': Could not match any condition to 'region' in database
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load condition 'region{name="swamp,second-region"}' from fishing drop table 'overriding-drop-table': Could not match any condition to 'region' in database
- [20:29:01] [Server thread/WARN]: [MMOCore] Could not load loot chest region 'sample-region' from file 'default_loot_chests.yml': Could not find world 'world_name_here'
- [20:29:01] [Server thread/INFO]: [MMOCore] Hooked parties onto MMOCore
- [20:29:01] [Server thread/INFO]: [MMOCore] Hooked guilds onto MMOCore
- [20:29:01] [Server thread/INFO]: [MMOItems] Enabling MMOItems v6.10.1-SNAPSHOT
- [20:29:01] [Server thread/INFO]: [MMOItems] Hooked onto MythicMobs
- [20:29:01] [Server thread/INFO]: [MMOItems] Hooked onto MMOInventory
- [20:29:01] [Server thread/INFO]: [MMOItems] Hooked onto MMOCore
- [20:29:01] [Server thread/INFO]: [MMOItems] Now using MMOCore as RPG core plugin
- [20:29:01] [Server thread/INFO]: [MMOItems Template Modifiers] Loading template modifiers, please wait..
- [20:29:02] [Server thread/INFO]: [MMOItems Item Templates] Loading item templates, please wait...
- [20:29:02] [Server thread/INFO]: [MMOItems Item Templates (WAND)] Could not post-load item template 'OAK_WAND': Could not find stat with ID 'CUSTOM_ABILITYHASTE'
- [20:29:02] [Server thread/INFO]: [MMOItems Item Templates (WAND)] Could not post-load item template 'SIMPLEWAND': Could not find stat with ID 'CUSTOM_ABILITYHASTE'
- [20:29:02] [Server thread/INFO]: [MMOItems] Loading crafting stations, please wait..
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-helmet' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_HELM'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-chestplate' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_CHESTPLATE'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-leggings' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_LEGGINGS'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'arcane-boots' from crafting station 'arcane-forge': Could not find a template with ID 'ARCANE_BOOTS'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'cursed-wither-skull' from crafting station 'mythical-forge': Could not find a template with ID 'CURSED_WITHER_SKULL'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'dead-pharaoh-helmet' from crafting station 'mythical-forge': Could not find a template with ID 'DEAD_PHARAOH_HELMET'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'mossy-skeleton-skull' from crafting station 'mythical-forge': Could not find a template with ID 'MOSSY_SKELETON_SKULL'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-helmet' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_HELMET'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-chestplate' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_CHESTPLATE'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-leggings' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_LEGGINGS'
- [20:29:02] [Server thread/ERROR]: [MMOItems] Could not load recipe 'steel-boots' from crafting station 'steel-crafting-station': Could not find a template with ID 'STEEL_BOOTS'
- [20:29:02] [Server thread/INFO]: [MMOItems] Hooked onto MMOInventory
- [20:29:02] [Server thread/INFO]: [PlaceholderAPI] Successfully registered internal expansion: mmoitems [6.10.1-SNAPSHOT]
- [20:29:02] [Server thread/INFO]: [MMOItems] Hooked onto PlaceholderAPI
- [20:29:02] [Server thread/INFO]: [MMOItems] Loading recipes, please wait...
- [20:29:02] [Server thread/INFO]: [MythicCrucible] Enabling MythicCrucible v2.2.0-SNAPSHOT
- [20:29:02] [Server thread/INFO]: [MythicMobs] §6------------------------------------------------
- [20:29:02] [Server thread/INFO]: [MythicMobs] §b+ Loading MythicCrucible for Bukkit
- [20:29:02] [Server thread/INFO]: [MythicMobs] §6------------------------------------------------
- [20:29:02] [Server thread/INFO]: [MythicMobs] Registering Durability Listener
- [20:29:07] [Server thread/INFO]: [MythicMobs] Started up bStats Metrics
- [20:29:07] [Server thread/INFO]: [MythicMobs] MythicCrucible Support has been enabled!
- [20:29:07] [Server thread/INFO]: [MythicMobs] MythicCrucible WorldEdit support enabled!
- [20:29:07] [Server thread/INFO]: [MythicMobs] Attached traits to items.
- [20:29:07] [Server thread/INFO]: [MythicMobs] Loaded 3 items.
- [20:29:07] [Server thread/INFO]: [MythicMobs] Loaded 2 drop tables.
- [20:29:07] [Server thread/INFO]: [MythicMobs] ✓ MythicCrucible v2.2.0 has been successfully loaded!
- [20:29:07] [Server thread/INFO]: [MythicHUD] Enabling MythicHUD v1.3.1-SNAPSHOT
- [20:29:07] [Server thread/INFO]: [MythicHUD] Mythic support detected.
- [20:29:07] [Server thread/INFO]: [MythicHUD] PlaceholderAPI parser has been registered.
- [20:29:07] [Server thread/INFO]: [MythicHUD] Generating resource pack for all versions
- [20:29:07] [Server thread/INFO]: [MythicHUD] [ACF] Enabled Asynchronous Tab Completion Support!
- [20:29:07] [Server thread/INFO]: [AxiomPaper] Enabling AxiomPaper v5.0.1+1.21.5
- [20:29:07] [Server thread/INFO]: [SimpleScore] Enabling SimpleScore v4.0.1
- [20:29:08] [Server thread/INFO]: [MMOInventory] Enabling MMOInventory v2.0-SNAPSHOT
- [20:29:08] [Server thread/WARN]: [MMOInventory] Could not load message 'elytra-equip': Translation not found
- [20:29:08] [Server thread/WARN]: [MMOInventory] Could not load message 'elytra-unequip': Translation not found
- [20:29:08] [Server thread/WARN]: [MMOInventory] Could not load message 'inspect': Translation not found
- [20:29:08] [Server thread/INFO]: [spark] Starting background profiler...
- [20:29:08] [Server thread/INFO]: [PlaceholderAPI] Placeholder expansion registration initializing...
- [20:29:08] [Server thread/INFO]: Done preparing level "world" (11.479s)
- [20:29:08] [Server thread/INFO]: Running delayed init tasks
- [20:29:08] [Server thread/WARN]: [MythicMobs] ✗ Configuration Error in Mechanic CustomMechanic:NULL
- [20:29:08] [Server thread/WARN]: [MythicMobs] --| Skill: MeechLavaSwimSpeedTick | File: /home/ProjectCrimson/server/plugins/MythicMobs/skills/learningFolders/MeechSkills.yml
- [20:29:08] [Server thread/WARN]: [MythicMobs] --| Error Message: Failed to load custom mechanic HASAURA
- [20:29:08] [Server thread/WARN]: [MythicMobs] --| Mechanic Line: hasAura{LavaFlight}
- [20:29:08] [Server thread/INFO]: Done (18.039s)! For help, type "help"
- [20:29:08] [Craft Scheduler Thread - 6 - MMOInventory/INFO]: [MMOInventory] A new build is available: 1.9 (you are running 2.0-SNAPSHOT)
- [20:29:08] [Craft Scheduler Thread - 6 - MMOInventory/INFO]: [MMOInventory] Download it here: https://www.spigotmc.org/resources/99445/
- [20:29:08] [Server thread/INFO]: [PlaceholderAPI] Successfully registered external expansion: PAPIFormula [1.0.0]
- [20:29:08] [Server thread/INFO]: [PlaceholderAPI] Successfully registered external expansion: math [2.0.2]
- [20:29:08] [Server thread/INFO]: 2 placeholder hook(s) registered!
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Starting Pack Generator...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Processing MythicHUD Pack...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Custom Blocks...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Items...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Assigning Legacy CMD Materials...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Legacy Definitions...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Sounds...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Linking Custom Blocks...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generating Atlas...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Zipping Pack...
- [20:29:13] [Craft Scheduler Thread - 1 - MythicMobs/INFO]: [Generation] Generation Completed in 68ms
- [20:29:21] [User Authenticator #0/INFO]: UUID of player Sukichan is fcd961d5-3a14-3910-97ee-06060bf286b8
- [20:29:21] [Server thread/INFO]: Sukichan joined the game
- [20:29:21] [Server thread/INFO]: Sukichan[/192.168.1.239:52769] logged in with entity id 287 at ([world]102.35984620592187, 114.0, -53.783073492140915)
- [20:29:31] [Server thread/INFO]: Sukichan issued server command: /mm debug
- [20:29:35] [Server thread/INFO]: Sukichan issued server command: /mm debug 4
- [20:29:38] [Server thread/INFO]: Sukichan issued server command: /mm test cast applyTest
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic skill:applyDebuff{aura=debuff3;duration=2000;interval=10;onTick=[]} @self
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic metaskill is usable!
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic metaskill with power 1 (line: skill:applyDebuff{aura=debuff3;duration=2000;interval=10;onTick=[]} @self)
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : EntityTargeter found 1 targets
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Applying entity target filters
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Returning 1 targets
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- Running Skill applyDebuff Async from MetaSkillMechanic
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic message{m="Applying<&sp><skill.aura><&sp>to<&sp><target.name>"} @caster
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic message is usable!
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic message with power 1 (line: message{m="Applying<&sp><skill.aura><&sp>to<&sp><target.name>"} @caster)
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : EntityTargeter found 1 targets
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Applying entity target filters
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Returning 1 targets
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic accepts multiple types...
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Mechanic is ITargetedEntitySkill
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic io.lumine.mythic.core.skills.mechanics.MessageMechanic is an ENTITY skill. Executing...
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic setVariable{name=target.debuffs;type=LIST;value=""} ?!variableIsSet{name=target.debuffs}
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- ! SkillMechanic not usable: Condition variableIsSet failed
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic addVariable{name=target.debuffs;value=<skill.aura>}
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic variableAdd is usable!
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic variableAdd with power 1 (line: addVariable{name=target.debuffs;value=<skill.aura>})
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Mechanic is ITargetedEntitySkill
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic io.lumine.mythic.core.skills.mechanics.VariableAddMechanic is an ENTITY skill. Executing...
- [20:29:38] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic aura{aura=<skill.aura>;interval=<skill.interval>;d=<skill.duration>;<&csp>ontickskill=[<&da><&csp>vskill{skill=<skill.onTick>}];onendskill=[<&csp><&da><&csp>delay<&csp>1<&csp><&da><&csp>skill:removeDebuff{value=<skill.aura>}];<&csp>showbartimer=true;<&csp>coq=true<&csp>}
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- + SkillMechanic aura is usable!
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Executing SkillMechanic aura with power 1 (line: aura{aura=<skill.aura>;interval=<skill.interval>;d=<skill.duration>;<&csp>ontickskill=[<&da><&csp>vskill{skill=<skill.onTick>}];onendskill=[<&csp><&da><&csp>delay<&csp>1<&csp><&da><&csp>skill:removeDebuff{value=<skill.aura>}];<&csp>showbartimer=true;<&csp>coq=true<&csp>})
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic accepts multiple types...
- [20:29:38] [Server thread/INFO]: [MythicMobs] |----- Mechanic is ITargetedEntitySkill
- [20:29:38] [Server thread/INFO]: [MythicMobs] |------- : SkillMechanic io.lumine.mythic.core.skills.mechanics.AuraMechanic is an ENTITY skill. Executing...
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:38] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:39] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:40] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:41] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic vskill{skill=<skill.onTick>}
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- + SkillMechanic metavariableskill is usable!
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- Executing SkillMechanic metavariableskill with power 1 (line: vskill{skill=<skill.onTick>})
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |------- : SkillMechanic is a META mechanic. Executing...
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:42] [lumine-scheduler-0/INFO]: [MythicMobs] +--- Running Skill <skill.onTick> Async from MetaSkillMechanic
- [20:29:42] [Server thread/INFO]: Sukichan lost connection: Disconnected
- [20:29:42] [Server thread/INFO]: [MythicMobs] |----- ! Skill usable!
- [20:29:42] [Server thread/INFO]: [MythicMobs] +--- + Evaluating SkillMechanic delay 1
- [20:29:42] [Server thread/INFO]: [MythicMobs] [i] Updating Armor
- [20:29:42] [Server thread/INFO]: Sukichan left the game
- [20:29:54] [User Authenticator #0/INFO]: UUID of player Sukichan is fcd961d5-3a14-3910-97ee-06060bf286b8
- [20:29:54] [Server thread/INFO]: [MythicMobs] [i] CrucibleProfile not loaded yet for Sukichan
- [20:29:54] [Server thread/INFO]: Sukichan joined the game
- [20:29:54] [Server thread/INFO]: Sukichan[/192.168.1.239:52792] logged in with entity id 364 at ([world]102.35984620592187, 114.0, -53.783073492140915)
- [20:29:54] [Server thread/INFO]: [MythicMobs] [i] Loaded profile for Sukichan
- [20:29:54] [Server thread/INFO]: [MythicMobs] [i] Parsing Weapon for Sukichan
- [20:29:55] [Server thread/INFO]: [MythicMobs] [i] Updating Armor (Delayed)
- [20:29:55] [Server thread/INFO]: [MythicMobs] [i] Updating Armor
- [20:30:02] [Server thread/INFO]: [MythicMobs] [i] Calling MythicMobSpawnEvent for SkeletalKnight (level: 2.0)
- [20:30:03] [Server thread/INFO]: [MythicMobs] +--- Generating LootBag
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_HELMET HEAD amount 1
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_HELMET HEAD
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_CHESTPLATE CHEST amount 1
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_CHESTPLATE CHEST
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_LEGGINGS LEGS amount 1
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_LEGGINGS LEGS
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_BOOTS FEET amount 1
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_BOOTS FEET
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item IRON_SWORD HAND amount 1
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: IRON_SWORD HAND
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Handling Item SHIELD OFFHAND amount 1
- [20:30:03] [Server thread/INFO]: [MythicMobs] |------- Adding Drop to LootBag: SHIELD OFFHAND
- [20:30:12] [Server thread/INFO]: Sukichan issued server command: /stop
- [20:30:12] [Server thread/INFO]: [Sukichan: Stopping the server]
- [20:30:12] [Server thread/INFO]: Stopping server
- [20:30:12] [Server thread/INFO]: [MMOInventory] Disabling MMOInventory v2.0-SNAPSHOT
- [20:30:12] [Server thread/INFO]: [WorldEdit] Disabling WorldEdit v7.3.16+cbf4bd5
- [20:30:12] [Server thread/INFO]: Unregistering com.sk89q.worldedit.bukkit.BukkitServerInterface from WorldEdit
- [20:30:12] [Server thread/INFO]: [SimpleScore] Disabling SimpleScore v4.0.1
- [20:30:12] [Server thread/INFO]: [AxiomPaper] Disabling AxiomPaper v5.0.1+1.21.5
- [20:30:12] [Server thread/INFO]: [MythicHUD] Disabling MythicHUD v1.3.1-SNAPSHOT
- [20:30:12] [Server thread/INFO]: [MythicCrucible] Disabling MythicCrucible v2.2.0-SNAPSHOT
- [20:30:12] [Server thread/INFO]: [MMOItems] Disabling MMOItems v6.10.1-SNAPSHOT
- [20:30:12] [Server thread/INFO]: [MMOCore] Disabling MMOCore v1.13.1-SNAPSHOT
- [20:30:12] [Server thread/INFO]: [PlaceholderAPI] Unregistered placeholder expansion PAPIFormula
- [20:30:12] [Server thread/INFO]: [PlaceholderAPI] Reason: required plugin MMOCore was disabled.
- [20:30:13] [Server thread/INFO]: [MythicLib] Disabling MythicLib v1.7.1-SNAPSHOT
- [20:30:13] [Server thread/INFO]: [MythicMobs] Disabling MythicMobs v5.10.1-SNAPSHOT-ae8b9c3d
- [20:30:13] [Server thread/INFO]: [MythicMobs] ------------------------------------------------------------
- [20:30:13] [Server thread/INFO]: [MythicMobs] -
- [20:30:13] [Server thread/INFO]: [MythicMobs] - Unloading Mythic...
- [20:30:13] [Server thread/INFO]: [MythicMobs] -
- [20:30:13] [Server thread/INFO]: [MythicMobs] ------------------------------------------------------------
- [20:30:13] [Server thread/INFO]: [MythicMobs] - Spawners saved and unloaded...
- [20:30:13] [Server thread/INFO]: [MythicMobs] +--- Running Mechanics for ActiveMob SkeletalKnight (uuid: e55d4346-6151-4bfe-9db0-a8e03c860cfd)
- [20:30:13] [Server thread/INFO]: [MythicMobs] - Mobs saved and unloaded...
- [20:30:13] [Server thread/INFO]: [MythicMobs] Saving plugin data...
- [20:30:13] [Server thread/INFO]: [MythicMobs] ✓Saving Finished
- [20:30:13] [Server thread/INFO]: [MythicMobs] - Variables saved...
- [20:30:13] [Server thread/INFO]: [MythicMobs] - All active settings have been saved!
- [20:30:13] [Server thread/INFO]: [MythicMobs] - Mythic has been unloaded!
- [20:30:13] [Server thread/INFO]: [MythicMobs] ------------------------------------------------------------
- [20:30:13] [Server thread/INFO]: [MythicMobs] Saving plugin data...
- [20:30:13] [Server thread/INFO]: [MythicMobs] ✓Saving Finished
- [20:30:13] [Server thread/INFO]: [LibsDisguises] Disabling LibsDisguises v11.0.9
- [20:30:13] [Server thread/INFO]: [PlaceholderAPI] Disabling PlaceholderAPI v2.11.6
- [20:30:13] [Server thread/INFO]: [packetevents] Disabling packetevents v2.10.0
- [20:30:13] [Server thread/INFO]: [ProtocolLib] Disabling ProtocolLib v5.4.0
- [20:30:13] [Server thread/INFO]: Saving players
- [20:30:13] [Server thread/INFO]: Sukichan lost connection: Server closed
- [20:30:13] [Server thread/INFO]: Sukichan left the game
- [20:30:13] [Server thread/INFO]: Saving worlds
- [20:30:13] [Server thread/INFO]: Saving chunks for level 'ServerLevel[world]'/minecraft:overworld
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk system to halt for world 'world'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted chunk system for world 'world'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saving all chunkholders for world 'world'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saved 625 block chunks, 625 entity chunks, 0 poi chunks in world 'world' in 0.23s
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk I/O to halt for world 'world'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted I/O scheduler for world 'world'
- [20:30:13] [Server thread/INFO]: Saving chunks for level 'ServerLevel[world_nether]'/minecraft:the_nether
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk system to halt for world 'world_nether'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted chunk system for world 'world_nether'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saving all chunkholders for world 'world_nether'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saved 49 block chunks, 49 entity chunks, 0 poi chunks in world 'world_nether' in 0.05s
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk I/O to halt for world 'world_nether'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted I/O scheduler for world 'world_nether'
- [20:30:13] [Server thread/INFO]: Saving chunks for level 'ServerLevel[world_the_end]'/minecraft:the_end
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk system to halt for world 'world_the_end'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted chunk system for world 'world_the_end'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saving all chunkholders for world 'world_the_end'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Saved 49 block chunks, 49 entity chunks, 0 poi chunks in world 'world_the_end' in 0.01s
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Waiting 60s for chunk I/O to halt for world 'world_the_end'
- [20:30:13] [Server thread/INFO]: [ChunkHolderManager] Halted I/O scheduler for world 'world_the_end'
- [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage (world): All chunks are saved
- [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage (DIM-1): All chunks are saved
- [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage (DIM1): All chunks are saved
- [20:30:13] [Server thread/INFO]: ThreadedAnvilChunkStorage: All dimensions are saved
- [20:30:13] [Server thread/INFO]: Waiting for all RegionFile I/O tasks to complete...
- [20:30:13] [Server thread/INFO]: All RegionFile I/O tasks to complete
- [20:30:13] [Server thread/INFO]: [MoonriseCommon] Awaiting termination of worker pool for up to 60s...
- [20:30:13] [Server thread/INFO]: [MoonriseCommon] Awaiting termination of I/O pool for up to 60s...
Add Comment
Please, Sign In to add comment